unit DataModule;

interface

uses
  SysUtils, Classes, AutoListUtils, Rdf_1_1, RdfParser_1_1;

type
  TRdfDataModule = class(TDataModule)
    RdfParser: TRdfNTripleToRdfGraphParser;
    ClassGraph: TRdfDetailGraph;
    PropertyGraph: TRdfDetailGraph;
    RdfAbbreviations: TUtilsAutoAliases;
    ClassList: TRdfResourceList;
    PropertyList: TRdfResourceList;
    LabelQueryGraph: TRdfDetailGraph;
    DescriptionQueryGraph: TRdfDetailGraph;
    ClassIterator: TUtilsStringIterator;
    PropertyIterator: TUtilsStringIterator;
    MainGraph: TRdfFilteredGraph;
    procedure DataModuleCreate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    function DescriptionOf(S: string): string;
    function LabelOf(S: string): string;
    procedure ParseFile(Path: TFilename);
  end;

var
  RdfDataModule: TRdfDataModule;

implementation

uses
  main;

{$R *.dfm}

{ TRdfDataModule }

procedure TRdfDataModule.ParseFile(Path: TFilename);
var
  Handle: Integer;
begin
  Handle:= 0; // Handle is used to destinguish the local ID's of blank nodes
              // Passing a zero Handle the Parse() method below, aquires a
              // new handled (>0) returned by the parser.  This can be reused
              // later to add blank nodes with the same local name.
  MainGraph.Clear;
  RdfParser.ParseFile(Path,Handle);
  ClassIterator.First;
  PropertyIterator.First;
end;

procedure TRdfDataModule.DataModuleCreate(Sender: TObject);
begin
  // Initializing the RdfAbbreviations component.
  RdfAbbreviations.Define('<http://www.w3.org/1999/02/22-rdf-syntax-ns#','<rdf:');
  RdfAbbreviations.Define('<http://www.w3.org/2000/01/rdf-schema#','<rdfs:');
end;

function TRdfDataModule.DescriptionOf(S: string): string;
begin
  with DescriptionQueryGraph do begin
    Filter.SubjectQualifier := S;
    ForceUpdate;
    if Count > 0
      then Result := GetStatementAttribute(0, saObjectLexical)
      else Result := '';
  end;
end;

function TRdfDataModule.LabelOf(S: string): string;
begin
  with LabelQueryGraph do begin
    Filter.SubjectQualifier := S;
    ForceUpdate;
    if Count > 0
      then Result := GetStatementAttribute(0, saObjectLexical)
      else Result := '';
  end;
end;

end.
