unit DataModule;

interface

uses
  RdfParser_1_1, Rdf_1_1, AutoListUtils, SysUtils, Classes;

type
  TRdfDataModule = class(TDataModule)
    RdfAbbreviations: TUtilsAutoAliases;
    SubjectList: TRdfGraphList;
    PredicateList: TRdfGraphList;
    ObjectList: TRdfGraphList;
    LexicalList: TRdfGraphList;
    LanguageList: TRdfGraphList;
    DatatypeList: TRdfGraphList;
    SubjectSrc: TUtilsStringIterator;
    PredicateSrc: TUtilsStringIterator;
    ObjectSrc: TUtilsStringIterator;
    LexicalSrc: TUtilsStringIterator;
    LanguageSrc: TUtilsStringIterator;
    DatatypeSrc: TUtilsStringIterator;
    MainSrc: TRdfGraphIterator;
    MainRdfGraph: TRdfFilteredGraph;
    Parser: TRdfNTripleToRdfGraphParser;
    LabelMap: TRdfAliases;
    CommentMap: TRdfAliases;
    SubjectLabelList: TRdfGraphList;
    SubjectLabelSrc: TUtilsStringIterator;
    SubjectCommentList: TRdfGraphList;
    SubjectCommentSrc: TUtilsStringIterator;
    procedure DataModuleCreate(Sender: TObject);
    procedure MainSrcPositionChanged(Sender: TObject; OldPos,
      NewPos: Integer);
  private
    function GetUseAbbreviations: Boolean;
    procedure SetUseAbbreviations(const Value: Boolean);
    { Private declarations }
  public
    { Public declarations }
    procedure ParseFile(Path: TFilename);
    property UseAbbreviations: Boolean read GetUseAbbreviations write SetUseAbbreviations;
      // We use this property as convinient method to switch abbreviations on and off.
  end;

var
  RdfDataModule: TRdfDataModule;

implementation

uses
  main;

{$R *.dfm}

{ TRdfDataModule }

procedure TRdfDataModule.ParseFile(Path: TFilename);
var
  Handle: Integer;
begin
  Handle:= 0; // Handle is used to destinguish the local ID's of blank nodes
              // Passing a zero Handle the Parse() method below, aquires a
              // new handled (>0) returned by the parser.  This can be reused
              // later to add blank nodes with the same local name.
  MainRdfGraph.Clear;
  Parser.ParseFile(Path,Handle);
  MainSrc.First;
end;

procedure TRdfDataModule.DataModuleCreate(Sender: TObject);
begin
  // Initializing the RdfAbbreviations component.
  RdfAbbreviations.Define('<http://www.w3.org/1999/02/22-rdf-syntax-ns#','<rdf:');
  RdfAbbreviations.Define('<http://www.w3.org/2000/01/rdf-schema#','<rdfs:');
end;

function TRdfDataModule.GetUseAbbreviations: Boolean;
begin
  Result := SubjectList.AliasOpt = aoPrefix;
end;

procedure TRdfDataModule.SetUseAbbreviations(const Value: Boolean);

// This procedure switches the use of abbreviations for all RDF Graphs in
// the data module.

begin
  if Value then begin
    SubjectList.AliasOpt   := aoPrefix;
    PredicateList.AliasOpt := aoPrefix;
    ObjectList.AliasOpt    := aoPrefix;
    LexicalList.AliasOpt   := aoPrefix;
    LanguageList.AliasOpt  := aoPrefix;
    DatatypeList.AliasOpt  := aoPrefix;
  end else begin
    SubjectList.AliasOpt   := aoOff;
    PredicateList.AliasOpt := aoOff;
    ObjectList.AliasOpt    := aoOff;
    LexicalList.AliasOpt   := aoOff;
    LanguageList.AliasOpt  := aoOff;
    DatatypeList.AliasOpt  := aoOff;
  end;
end;

procedure TRdfDataModule.MainSrcPositionChanged(Sender: TObject; OldPos,
  NewPos: Integer);

  // The navigator controls of the user interface are connected to MainSrc.
  // Here, we synchronize the position of the other iterators with MainSrc.

begin
  if csDestroying in ComponentState then Exit;

  SubjectSrc.Go(NewPos);
  PredicateSrc.Go(NewPos);
  ObjectSrc.Go(NewPos);
  LexicalSrc.Go(NewPos);
  LanguageSrc.Go(NewPos);
  DatatypeSrc.Go(NewPos);

  SubjectLabelSrc.Go(NewPos);
  SubjectCommentSrc.Go(NewPos);
end;

end.
