unit DataModule;

interface

uses
  AutoListUtils, SysUtils, Classes, Rdf_1_1, RdfParser_1_1,
  RdfSerializer_1_0;

type
  TRdfDataModule = class(TDataModule)
    Aliases: TUtilsAutoAliases;
    PredicatesList: TRdfResourceList;
    PredicatesIterator: TUtilsStringIterator;
    ObjectIterator: TUtilsStringIterator;
    AliasedSubjectIterator: TUtilsStringIterator;
    AliasedSubjectList: TRdfResourceList;
    Parser: TRdfNTripleToRdfGraphParser;
    MainRdfGraph: TRdfFilteredGraph;
    LabelMap: TRdfAliases;
    PredicateView: TRdfRestricterGraph;
    ObjectView: TRdfRestricterGraph;
    ObjectList: TRdfResourceList;
    RdfSerializer: TRdfNTripleToRdfGraphSerializer;
    procedure DataModuleCreate(Sender: TObject);
    procedure IteratorListModified(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    function GetCurrentObjectLiteral: string;
    function LabelOf(S: string): string;
    procedure ParseFile(Path: TFilename);
    procedure SwitchSubjectTo(S: string);
  end;

var
  RdfDataModule: TRdfDataModule;

implementation

{$R *.dfm}

procedure TRdfDataModule.DataModuleCreate(Sender: TObject);
begin
  // Initializing the Aliases component.
  with Aliases do begin
    BeginUpdate;
    try
      Define('<http://www.w3.org/1999/02/22-rdf-syntax-ns#','<rdf:');
      Define('<http://www.w3.org/2000/01/rdf-schema#','<rdfs:');
    finally
      EndUpdate;
    end;
  end;
end;

function TRdfDataModule.GetCurrentObjectLiteral: string;
begin
  if ObjectView.Count > 0
    then Result := ObjectView.GetStatementAttribute(0, saObjectLexical)
    else Result := '';
end;

procedure TRdfDataModule.IteratorListModified(Sender: TObject);
begin
  (Sender as TUtilsStringIterator).First;
end;

function TRdfDataModule.LabelOf(S: string): string;
var
  I: Integer;
begin
  I := LabelMap.IndexOfKey(S);
  if I = -1
    then Result := ''
    else Result := LabelMap.Alias[I];
end;

procedure TRdfDataModule.ParseFile(Path: TFilename);
var
  Handle: Integer;
begin
  Handle:= 0; // Handle is used to destinguish the local ID's of blank nodes
              // Passing a zero Handle the Parse() method below, aquires a
              // new handled (>0) returned by the parser.  This can be reused
              // later to add blank nodes with the same local name.
  Parser.ParseFile(Path,Handle);
end;

procedure TRdfDataModule.SwitchSubjectTo(S: string);
var
  I: Integer;
begin
  with AliasedSubjectIterator do begin
    I := AliasedSubjectList.IndexOfLiteral(S, 1);
    if I > -1 then Go(I);
  end;
end;

end.
